==> qtjambi-charts-debuginfo-windows-x64-6.5.8.jar: sources/QtJambiCharts/QCandlestickSet_shell.h <==
#ifndef QCANDLESTICKSET_SHELL_H
#define QCANDLESTICKSET_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtCharts/qcandlestickset.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtGui/qbrush.h>
#include <QtGui/qpen.h>
#include <QtJambi/RegistryAPI>


class QCandlestickSet_shell : public QCandlestickSet, public QtJambiShellInterface
{
public:
    QCandlestickSet_shell(qreal timestamp0 = 0.0, QObject* parent1 = nullptr);
    QCandlestickSet_shell(qreal open0, qreal high1, qreal low2, qreal close3, qreal timestamp4 = 0.0, QObject* parent5 = nullptr);
    ~QCandlestickSet_shell() override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    friend class QCandlestickSet_mshell;
    friend class QCandlestickSet_oshell;
};


class QCandlestickSet_mshell : public QCandlestickSet_shell
{
public:
    using QCandlestickSet_shell::QCandlestickSet_shell;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
};


class QCandlestickSet_oshell : public QCandlestickSet_mshell
{
public:
    using QCandlestickSet_mshell::QCandlestickSet_mshell;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
private:
    jmethodID __shell_javaMethod(int pos) const;
};

struct QCandlestickSet_access : public QCandlestickSet
{
};

#endif // QCANDLESTICKSET_SHELL_H

==> qtjambi-charts-debuginfo-windows-x64-6.6.0.jar: sources/QtJambiCharts/QCandlestickSet_shell.h <==
#ifndef QCANDLESTICKSET_SHELL_H
#define QCANDLESTICKSET_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtCharts/qcandlestickset.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qvariant.h>
#include <QtGui/qbrush.h>
#include <QtGui/qpen.h>
#include <QtJambi/RegistryAPI>


class QCandlestickSet_shell : public QCandlestickSet, public QtJambiShellInterface
{
public:
    QCandlestickSet_shell(qreal open0, qreal high1, qreal low2, qreal close3, qreal timestamp4 = 0.0, QObject* parent5 = nullptr);
    QCandlestickSet_shell(qreal timestamp0 = 0.0, QObject* parent1 = nullptr);
    ~QCandlestickSet_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QCandlestickSet_access : public QCandlestickSet
{
};

#endif // QCANDLESTICKSET_SHELL_H
